Trot v0.7.0 Trot View Source

Main Trot application. When added to a projects application list, Trot.Supervisor will be started. Also contains some generic parsing functions.

Link to this section Summary

Functions

Returns a boolean indicating whether the passed in atom is a valid HTTP method

Parses a query string into a keyword list

Link to this section Functions

Link to this macro is_http_method(thing) View Source (macro)

Returns a boolean indicating whether the passed in atom is a valid HTTP method.

Link to this function parse_query_string(string) View Source

Parses a query string into a keyword list.