Trot v0.7.0 Trot.LiveReload View Source
Plug for reloading modules on every request, allowing fast iteration during development.
Reloading only happens in dev, every other environment is a noop for this plug. If a module is reloaded, a redirect is sent to the client for the same location, allowing the whole plug pipeline to be used with the new code. All further processing on the original request is halted.
Modified from https://github.com/sugar-framework/plugs/blob/master/lib/sugar/plugs/hot_code_reload.ex
Link to this section Summary
Link to this section Functions
Recompiles any modules that have changed. This is similar to how IEx handles recompilation, but only for the elixir compiler. https://github.com/elixir-lang/elixir/blob/v1.3.2/lib/iex/lib/iex/helpers.ex#L77